@@ -108,7 +108,7 @@ class System(pc.System):
             summ += np.dot(box1, box2)/(np.linalg.norm(box1)*np.linalg.norm(box2))
 
         #check if the summ is zero
-        if np.abs(summ) > 0:
+        if (np.abs(summ) > 1E-6):
             #this is a triclinic box
             rot = np.array(userbox).T
             rotinv = np.linalg.inv(rot)
@@ -531,7 +531,11 @@ class System(pc.System):
             #copy the simulation cell
             backupbox = self._box.copy()
             if self.triclinic:
-                self.embed_in_cubic_box()
+                if not self.ghosts_created:
+                    atoms  = self.get_atoms()
+                    atoms = self.repeat((1, 1, 1), atoms=atoms, ghost=True, scale_box=True)
+                    self.set_atoms(atoms)
+                    self.embed_in_cubic_box()
             #self.embed_in_cubic_box()
             self.get_all_neighbors_voronoi()
 
